@@ -39,7 +39,7 @@ class DDGTestCase(PluginTestCase):
 
         def testSearch(self):
             self.assertRegexp(
-                'ddg search wikipedia', 'Wikipedia.*? - .*?https?\:\/\/')
+                'ddg search wikipedia', r'Wikipedia.*? - .*?https?\:\/\/')
             self.assertRegexp(
                 'ddg search en.wikipedia.org',
                 'Wikipedia, the free encyclopedia\x02 - '
@@ -47,6 +47,6 @@ class DDGTestCase(PluginTestCase):
             with conf.supybot.plugins.DDG.region.context('fr-fr'):
                 self.assertRegexp(
                     'ddg search wikipedia',
-                    'Wikipédia, l\'encyclopédie libre - .*?https?\:\/\/')
+                    r'Wikipédia, l\'encyclopédie libre - .*?https?\:\/\/')
 
 # vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
