@@ -39,11 +39,11 @@ import supybot.ircdb as ircdb
 import supybot.utils as utils
 from supybot.commands import *
 import supybot.plugins as plugins
-import supybot.utils.minisix as minisix
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
 import supybot.httpserver as httpserver
 from supybot.i18n import PluginInternationalization, internationalizeDocstring
+from supybot.dynamicScope import dynamic
 _ = PluginInternationalization('Factoids')
 
 import sqlite3
@@ -223,12 +223,8 @@ class Factoids(callbacks.Plugin, plugins.ChannelDBHandler):
     def makeDb(self, filename):
         if os.path.exists(filename):
             db = sqlite3.connect(filename)
-            if minisix.PY2:
-                db.text_factory = str
             return db
         db = sqlite3.connect(filename)
-        if minisix.PY2:
-            db.text_factory = str
         cursor = db.cursor()
         cursor.execute("""CREATE TABLE keys (
                           id INTEGER PRIMARY KEY,
